@@ -1,49 +1,39 @@
 {
     "ReleaseInfos": {
+        "FileConfig": "",
+        "FileCollection": "",
         "VersionNumber": "1200",
-        "ReleaseDate": "211220",
-        "DocPartialPath": "/documentation/index.html",
-        "DocAbsolutePath": "https://github.com/parisolab/mathmod/wiki/documentation"
+        "ReleaseDateYMD": "250220",
+        "DocAbsolutePath": "https://github.com/parisolab/mathmod/wiki/documentation",
+        "DocPartialPath": "../Resources/documentation/index.html"
     },
     "Parameters": {
+        "AutomaticInitGrid": false,
         "IsoMaxGrid": 500,
-        "InitIsoGrid": 41,
+        "InitIsoGrid": 64,
         "ParMaxGrid": 5000,
-        "InitParGrid": 64,
+        "InitParGrid": 112,
         "ScriptEditorFontSize": 18
     },
     "StartOptions": {
         "Model": "CloseIso_1"
     },
-    "StartOptions": {
-        "Model": "CloseIso_1"
-    },
     "ThreadsConfig": {
         "AutoDetect": true,
         "ThreadsNumber": 8,
         "MinThreadsNumber": 1,
-        "MaxThreadsNumber": 64
-    },
-    "WindowSize": {
-        "ControlH": 750,
-        "ControlW": 1200,
-        "GlwinH": 750,
-        "GlwinW": 750
-    },
-    "WindowPosition": {
-        "ControlX": 80,
-        "ControlY": 30,
-        "GlwinX": 535,
-        "GlwinY": 30
+        "MaxThreadsNumber": 256
     },
     "Localization": {
         "AutomaticDetection": true,
         "DotSymbol": "."
     },
     "CalculFactorConfig": {
-        "FactX": 4,
-        "FactY": 4,
-        "FactZ": 4
+        "IsoFactX": 4,
+        "IsoFactY": 4,
+        "IsoFactZ": 4,
+        "ParFactU": 8,
+        "ParFactV": 8
     },
     "OpenGlConfig": {
         "GL_SPECULAR": [50, 50, 50, 100],
