@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2024 by Abderrahman Taha                                *
+ *   Copyright (C) 2025 by Abderrahman Taha                                *
  *                                                                         *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -19,8 +19,20 @@
  ***************************************************************************/
 #ifndef PARISOOBJECT_H
 #define PARISOOBJECT_H
+
+#define VECT_STR      TextureInfos[0]
+#define GRID_STR      TextureInfos[1]
+#define CONST_STR     TextureInfos[2]
+#define FUNCT_STR     TextureInfos[3]
+#define RGBT_STR      TextureInfos[4]
+#define VRGBT_STR     TextureInfos[5]
+#define GRADIENT_STR  TextureInfos[6]
+#define NOISE_STR     TextureInfos[7]
+
+
 #include "commun.h"
 
+
 class ParisoObject : public QThread
 {
 public:
@@ -34,6 +46,10 @@ public:
     bool StopCalculations;
     ScriptErrorType messageerror;
     QString message;
+    static std::vector<uint>  IndexPolyTabVector;
+    static std::vector<float> NormVertexTabVector;
+    static std::vector<uint> IndexPolyTabMinVector;
+    static std::vector<uint> IndexPolyTabMinVector2;
 };
 
 class WorkerThread : public QThread
@@ -41,11 +57,13 @@ class WorkerThread : public QThread
 public:
     WorkerThread();
     ~WorkerThread();
+    uint count_comma(const std::string);
 public:
-    uint CurrentComponent, MyIndex, WorkerThreadsNumber, iStart, iFinish;
+    uint CurrentComponent, ThreadIndex, WorkerThreadsNumber, iStart, iFinish, StackFactor;
     double stepMorph=0.0, pace=0.0;
     bool StopCalculations, ParsersAllocated, ParsersAllocated_C;
     int activeMorph, signalVal;
+    int *ptStackFactor;
 };
 
 class MasterThread
@@ -54,13 +72,15 @@ public:
     FunctionParser *ParisoConditionParser, *RgbtParser, *VRgbtParser,
                    *GradientParser, *NoiseParser, *NoiseShapeParser, Cstparser;
     FunctionParser_cd *RgbtParser_C;
-    std::vector<std::string> Rgbts, RgbtNames, VRgbts, VRgbtNames, Functs,
+    std::vector<InternalFuncDefinition> ImportedInternalFunctions;
+    std::vector<std::string> Rgbts, VRgbts, Functs,
         FunctNames, Consts, ConstNames, SliderNames;
-    std::string Vect, Grid, Const, Funct, Rgbt, VRgbt, Gradient, Noise;
+    std::string TextureInfos[10];
+    std::string Vect, Grid, Const, Funct;
     uint RgbtSize, FunctSize, VRgbtSize, ConstSize, Nb_Sliders;
     std::vector<uint> grid, vect;
     bool *UsedFunct, *UsedFunct2, gridnotnull, vectnotnull, constnotnull, functnotnull,
-         cndnotnull, rgbtnotnull, rgbtnotnull_C, vrgbtnotnull;
+         cndnotnull, rgbtnotnull, rgbtnotnull_C, vrgbtnotnull, importnotnull;
     std::vector<double> ConstValues, SliderValues;
     double Octaves, Lacunarity, Gain;
     int ParisoCondition;
@@ -68,6 +88,7 @@ public:
 public:
     MasterThread();
     ~MasterThread();
+    void clearTextureInfos();
 };
 
 #endif // PARISOOBJECT_H
