@@ -18,35 +18,39 @@
  *   51 Franklin Street, Fifth Floor,Boston, MA 02110-1301 USA             *
  ***************************************************************************/
 #include "video.h"
-
 screenimage::screenimage(QImage buffer) : QMainWindow(nullptr)
 {
     buf = buffer;
     image_quality = 1;
+    groupBox = new QGroupBox(this);
+    groupBox->setGeometry(QRect(0, 317, 320, 25));
     l = new QLabel(this);
     l->resize(320, 320);
     resize(320, 343);
     this->setWindowTitle("ScreenShot");
     QPixmap ScreenshotIcon = QPixmap::fromImage(buf.scaled(320, 320));
-    l->setPixmap(ScreenshotIcon); //  (ScreenshotIcon);
-    groupBox = new QGroupBox(this);
-    groupBox->setGeometry(QRect(0, 317, 320, 25));
-    scrollBar55 = new QScrollBar(Qt::Horizontal, nullptr);
+    l->setPixmap(ScreenshotIcon);
+    about = new QPushButton(groupBox);
+    about->setObjectName(QString::fromUtf8("about"));
+    about->setText("OK");
+    scrollBar55 = new QScrollBar(Qt::Horizontal, groupBox);
     scrollBar55->setGeometry(QRect(160, 2, 80, 16));
     scrollBar55->setPageStep(1);
     scrollBar55->setValue(1);
     pushScreenshot = new QPushButton("pushScreenshot", groupBox);
     pushScreenshot->setGeometry(QRect(250, 2, 75, 18));
     pushScreenshot->setText(tr("Save Screen"));
+    gridLayout = new QGridLayout(this);
+    gridLayout->addWidget(groupBox, 0, 0, 1, 1);
 }
 screenimage::~screenimage()
 {
-    // delete m;
     delete l;
 }
 void screenimage::connectcontrols()
 {
     connect(pushScreenshot, SIGNAL(clicked()), this, SLOT(saveas()));
+    connect(about, SIGNAL(clicked()), this, SLOT(close()));
     connect(scrollBar55, SIGNAL(valueChanged(int)), this, SLOT(f_1(int)));
 }
 void screenimage::f_1(int quality)
