@@ -1,5 +1,5 @@
 ﻿/***************************************************************************
- *   Copyright (C) 2024 by Abderrahman Taha                                *
+ *   Copyright (C) 2025 by Abderrahman Taha                                *
  *                                                                         *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -24,27 +24,25 @@ void MathMod::CalculateTexturePoints(int type)
 {
     double tmp, val[6]={0,0,0,0,0,0};
     uint Jprime;
+    LocalScene.componentsinfos.ThereisRGBA[0] = true;
+    LocalScene.componentsinfos.NoiseParam[0].NoiseType = 1;
     if (type == 1)
     {
-        LocalScene.componentsinfos.ThereisRGBA[0] = true;
-        LocalScene.componentsinfos.NoiseParam[0].NoiseType = 1;
         LocalScene.componentsinfos.NoiseParam[0].RgbtParser =
             IsoObjet->masterthread->RgbtParser;
         LocalScene.componentsinfos.NoiseParam[0].NoiseParser =
             IsoObjet->masterthread->NoiseParser;
-        IsoObjet->masterthread->Noise == ""
+        IsoObjet->masterthread->NOISE_STR == ""
         ? LocalScene.componentsinfos.NoiseParam[0].NoiseShape = 0
                 : LocalScene.componentsinfos.NoiseParam[0].NoiseShape = 1;
     }
-    else if (type == 0)
+    else // (type == 0)
     {
-        LocalScene.componentsinfos.ThereisRGBA[0] = true;
-        LocalScene.componentsinfos.NoiseParam[0].NoiseType = 1;
         LocalScene.componentsinfos.NoiseParam[0].RgbtParser =
             ParObjet->masterthread->RgbtParser;
         LocalScene.componentsinfos.NoiseParam[0].NoiseParser =
             ParObjet->masterthread->NoiseParser;
-        ParObjet->masterthread->Noise == ""
+        ParObjet->masterthread->NOISE_STR == ""
         ? LocalScene.componentsinfos.NoiseParam[0].NoiseShape = 0
                 : LocalScene.componentsinfos.NoiseParam[0].NoiseShape = 1;
     }
@@ -100,11 +98,11 @@ void MathMod::CalculateTexturePoints(int type)
 
 void MathMod::CalculatePigmentPoints(int type)
 {
-    double tmp, ValCol[100], val[4];
+    double tmp, val[4];
+    LocalScene.componentsinfos.ThereisRGBA[0] = true;
+    LocalScene.componentsinfos.NoiseParam[0].NoiseType = 0; // Pigments
     if (type == 1)
     {
-        LocalScene.componentsinfos.ThereisRGBA[0] = true;
-        LocalScene.componentsinfos.NoiseParam[0].NoiseType = 0; // Pigments
         LocalScene.componentsinfos.NoiseParam[0].VRgbtParser =
             IsoObjet->masterthread->VRgbtParser;
         LocalScene.componentsinfos.NoiseParam[0].GradientParser =
@@ -113,14 +111,12 @@ void MathMod::CalculatePigmentPoints(int type)
             IsoObjet->masterthread->VRgbtSize;
         LocalScene.componentsinfos.NoiseParam[0].NoiseParser =
             IsoObjet->masterthread->NoiseParser;
-        IsoObjet->masterthread->Noise == ""
+        IsoObjet->masterthread->NOISE_STR == ""
         ? LocalScene.componentsinfos.NoiseParam[0].NoiseShape = 0
                 : LocalScene.componentsinfos.NoiseParam[0].NoiseShape = 1;
     }
-    else if (type == 0)
+    else // (type == 0)
     {
-        LocalScene.componentsinfos.ThereisRGBA[0] = true;
-        LocalScene.componentsinfos.NoiseParam[0].NoiseType = 0; // Pigments
         LocalScene.componentsinfos.NoiseParam[0].VRgbtParser =
             ParObjet->masterthread->VRgbtParser;
         LocalScene.componentsinfos.NoiseParam[0].GradientParser =
@@ -129,16 +125,10 @@ void MathMod::CalculatePigmentPoints(int type)
             ParObjet->masterthread->VRgbtSize;
         LocalScene.componentsinfos.NoiseParam[0].NoiseParser =
             ParObjet->masterthread->NoiseParser;
-        ParObjet->masterthread->Noise == ""
+        ParObjet->masterthread->NOISE_STR == ""
         ? LocalScene.componentsinfos.NoiseParam[0].NoiseShape = 0
                 : LocalScene.componentsinfos.NoiseParam[0].NoiseShape = 1;
     }
-    for (uint i = 0;
-            i < LocalScene.componentsinfos.NoiseParam[0].Nb_vrgbts && i < 100; i++)
-    {
-        ValCol[i] =
-            LocalScene.componentsinfos.NoiseParam[0].VRgbtParser[i].Eval(val);
-    }
     for (uint i = 0; i < LocalScene.VertxNumber; i++)
     {
         val[0] = difMaximum *
@@ -164,28 +154,25 @@ void MathMod::CalculatePigmentPoints(int type)
         int c = int(tmp);
         tmp = std::abs(tmp - double(c));
         for (uint j = 0;
-                j < LocalScene.componentsinfos.NoiseParam[0].Nb_vrgbts && j < 100;
+                j < LocalScene.componentsinfos.NoiseParam[0].Nb_vrgbts && j < 95;
                 j += 5)
-            //ValCol array has undefined values
-            if (tmp <= ValCol[j])
+            if (tmp <= LocalScene.componentsinfos.NoiseParam[0].VRgbtParser[j].Eval(val))
             {
-                LocalScene.ArrayNorVer_localPt[i*10  ] = float(ValCol[j+1]);
-                LocalScene.ArrayNorVer_localPt[i*10+1] = float(ValCol[j+2]);
-                LocalScene.ArrayNorVer_localPt[i*10+2] = float(ValCol[j+3]);
-                LocalScene.ArrayNorVer_localPt[i*10+3] = float(ValCol[j+4]);
+                LocalScene.ArrayNorVer_localPt[i*10  ] = float(LocalScene.componentsinfos.NoiseParam[0].VRgbtParser[j+1].Eval(val));
+                LocalScene.ArrayNorVer_localPt[i*10+1] = float(LocalScene.componentsinfos.NoiseParam[0].VRgbtParser[j+2].Eval(val));
+                LocalScene.ArrayNorVer_localPt[i*10+2] = float(LocalScene.componentsinfos.NoiseParam[0].VRgbtParser[j+3].Eval(val));
+                LocalScene.ArrayNorVer_localPt[i*10+3] = float(LocalScene.componentsinfos.NoiseParam[0].VRgbtParser[j+4].Eval(val));
                 j = 100;
             }
     }
 }
 
-int MathMod::memoryallocation(uint nbthreads,
-                              uint initparGrid, uint initisoGrid,
-                              uint FactX, uint FactY, uint FactZ)
+int MathMod::memoryallocation(uint nbthreads, uint initparGrid, uint initisoGrid, int *pt)
 {
     try
     {
-        IsoObjet = new Iso3D(nbthreads, initisoGrid, FactX, FactY, FactZ);
-        ParObjet = new Par3D(nbthreads, initparGrid);
+        IsoObjet = new Iso3D(nbthreads, initisoGrid, pt);
+        ParObjet = new Par3D(nbthreads, initparGrid, pt);
         return 1;
     }
     catch (const std::bad_alloc&)
@@ -276,7 +263,7 @@ void MathMod::SaveSceneAsObjPoly(int type)
                 {
                     (stream) << "f "
                              << "  " << (i*vgrid + j+index) +1<< "  "
-                             << ((i+1)*vgrid + j +index) +1<< "  "
+                             << ((i+1)*vgrid + j+index) +1<< "  "
                              << ((i+1)*vgrid + (j+1)+index) +1<< "  "
                              << (i*vgrid + (j+1)+index) +1<< "\n";
                 }
@@ -305,7 +292,6 @@ void MathMod::SaveSceneAsObjPoly(int type)
                  }
                  index += ugrid*vgrid;
             }
-
            // Isosurface components
            startpl = LocalScene.PolyNumber+LocalScene.componentsinfos.MinParametricMeshLines;
            uint kl=  LocalScene.componentsinfos.NbParametricMeshLines;
@@ -452,7 +438,6 @@ void MathMod::PutObjectInsideCube()
                     (double(LocalScene.ArrayNorVer_localPt[10 * i + 9]) + decalage_zo) /
                     difMaximum);
     }
-
     // Cube vertices and indexes
     float longX = wh * float(difX / float(difMaximum)),
           longY = wh * (difY / float(difMaximum)),
@@ -466,55 +451,42 @@ void MathMod::PutObjectInsideCube()
         LocalScene.ArrayNorVer_localPt[10 * (NbVert+id) + 2] = 0.8f;
         LocalScene.ArrayNorVer_localPt[10 * (NbVert+id) + 3] = 1.0f;
     }
-
     LocalScene.ArrayNorVer_localPt[10 * NbVert + 7] = -longX;
     LocalScene.ArrayNorVer_localPt[10 * NbVert + 8] = -longY;
     LocalScene.ArrayNorVer_localPt[10 * NbVert + 9] = -longZ;
-
     LocalScene.ArrayNorVer_localPt[10 * (NbVert+1) + 7] =  longX;
     LocalScene.ArrayNorVer_localPt[10 * (NbVert+1) + 8] = -longY;
     LocalScene.ArrayNorVer_localPt[10 * (NbVert+1) + 9] = -longZ;
-
     LocalScene.ArrayNorVer_localPt[10 * (NbVert+2) + 7] =  longX;
     LocalScene.ArrayNorVer_localPt[10 * (NbVert+2) + 8] =  longY;
     LocalScene.ArrayNorVer_localPt[10 * (NbVert+2) + 9] = -longZ;
-
     LocalScene.ArrayNorVer_localPt[10 * (NbVert+3) + 7] = -longX;
     LocalScene.ArrayNorVer_localPt[10 * (NbVert+3) + 8] =  longY;
     LocalScene.ArrayNorVer_localPt[10 * (NbVert+3) + 9] = -longZ;
-
     LocalScene.ArrayNorVer_localPt[10 * (NbVert+4) + 7] = -longX;
     LocalScene.ArrayNorVer_localPt[10 * (NbVert+4) + 8] = -longY;
     LocalScene.ArrayNorVer_localPt[10 * (NbVert+4) + 9] = -longZ;
-
     LocalScene.ArrayNorVer_localPt[10 * (NbVert+5) + 7] = -longX;
     LocalScene.ArrayNorVer_localPt[10 * (NbVert+5) + 8] = -longY;
     LocalScene.ArrayNorVer_localPt[10 * (NbVert+5) + 9] =  longZ;
-
     LocalScene.ArrayNorVer_localPt[10 * (NbVert+6) + 7] = -longX;
     LocalScene.ArrayNorVer_localPt[10 * (NbVert+6) + 8] =  longY;
     LocalScene.ArrayNorVer_localPt[10 * (NbVert+6) + 9] =  longZ;
-
     LocalScene.ArrayNorVer_localPt[10 * (NbVert+7) + 7] = -longX;
     LocalScene.ArrayNorVer_localPt[10 * (NbVert+7) + 8] =  longY;
     LocalScene.ArrayNorVer_localPt[10 * (NbVert+7) + 9] = -longZ;
-
     LocalScene.ArrayNorVer_localPt[10 * (NbVert+8) + 7] = -longX;
     LocalScene.ArrayNorVer_localPt[10 * (NbVert+8) + 8] = -longY;
     LocalScene.ArrayNorVer_localPt[10 * (NbVert+8) + 9] = -longZ;
-
     LocalScene.ArrayNorVer_localPt[10 * (NbVert+9) + 7] = -longX;
     LocalScene.ArrayNorVer_localPt[10 * (NbVert+9) + 8] = -longY;
     LocalScene.ArrayNorVer_localPt[10 * (NbVert+9) + 9] =  longZ;
-
     LocalScene.ArrayNorVer_localPt[10 * (NbVert+10) + 7] =  longX;
     LocalScene.ArrayNorVer_localPt[10 * (NbVert+10) + 8] = -longY;
     LocalScene.ArrayNorVer_localPt[10 * (NbVert+10) + 9] =  longZ;
-
     LocalScene.ArrayNorVer_localPt[10 * (NbVert+11) + 7] =  longX;
     LocalScene.ArrayNorVer_localPt[10 * (NbVert+11) + 8] = -longY;
     LocalScene.ArrayNorVer_localPt[10 * (NbVert+11) + 9] = -longZ;
-
     // Plan vertices and indexes
     PlanStartIndex=NbVert+12;
     for(uint id=0; id<60; id++)
@@ -527,7 +499,6 @@ void MathMod::PutObjectInsideCube()
         LocalScene.ArrayNorVer_localPt[10*(NbVert+12+id)+8] = PlanArray[3*id+1];
         LocalScene.ArrayNorVer_localPt[10*(NbVert+12+id)+9] = PlanArray[3*id+2];
     }
-
     // Axes vertices and indexes
     AxesStartIndex = NbVert+12+60;
     for(uint id=0; id<6; id++)
@@ -540,7 +511,6 @@ void MathMod::PutObjectInsideCube()
         LocalScene.ArrayNorVer_localPt[10*(NbVert+12+60+id)+8] = AxeArray[3*id+1];
         LocalScene.ArrayNorVer_localPt[10*(NbVert+12+60+id)+9] = AxeArray[3*id+2];
     }
-
     // Head of the X Axe
     XStartIndex = NbVert+12+60+6;
     for(uint id=0; id<6; id++)
@@ -553,7 +523,6 @@ void MathMod::PutObjectInsideCube()
         LocalScene.ArrayNorVer_localPt[10*(NbVert+12+60+6+id)+8] = AxeArray[3*(id+6)+1];
         LocalScene.ArrayNorVer_localPt[10*(NbVert+12+60+6+id)+9] = AxeArray[3*(id+6)+2];
     }
-
     // Head of the Y Axe
     YStartIndex = NbVert+12+60+12;
     for(uint id=0; id<6; id++)
@@ -566,7 +535,6 @@ void MathMod::PutObjectInsideCube()
         LocalScene.ArrayNorVer_localPt[10*(NbVert+12+60+12+id)+8] = AxeArray[3*(id+12)+1];
         LocalScene.ArrayNorVer_localPt[10*(NbVert+12+60+12+id)+9] = AxeArray[3*(id+12)+2];
     }
-
     // Head of the Z Axe
     ZStartIndex = NbVert+12+60+18;
     for(uint id=0; id<6; id++)
@@ -579,7 +547,6 @@ void MathMod::PutObjectInsideCube()
         LocalScene.ArrayNorVer_localPt[10*(NbVert+12+60+18+id)+8] = AxeArray[3*(id+18)+1];
         LocalScene.ArrayNorVer_localPt[10*(NbVert+12+60+18+id)+9] = AxeArray[3*(id+18)+2];
     }
-
     // Letter X Axe
     XletterIndex = NbVert+12+60+24;
     for(uint id=0; id<4; id++)
@@ -617,13 +584,19 @@ void MathMod::PutObjectInsideCube()
         LocalScene.ArrayNorVer_localPt[10*(NbVert+12+60+32+id)+9] = AxeArray[3*(id+32)+2];
     }
     uint polynb=0;
+    uint grid=0;
     if(LocalScene.typedrawing == -1)
     {
         uint sz = LocalScene.componentsinfos.ParametricGrid.size();
+
         for (uint p = 0; p < sz; p += 2)
         {
-             polynb += (LocalScene.componentsinfos.ParametricGrid[p]-1) *
+            grid= (LocalScene.componentsinfos.ParametricGrid[p]*LocalScene.componentsinfos.ParametricGrid[p+1]);
+            if(grid!=0)
+                polynb += (LocalScene.componentsinfos.ParametricGrid[p]-1) *
                             (LocalScene.componentsinfos.ParametricGrid[p+1]-1);
+            else
+                polynb +=0;
         }
     }
     else
@@ -946,7 +919,6 @@ void MathMod::CreateShaderProgram()
     bool shaderValid;
 
     shaderprogramId = glCreateProgram();
-
     //+++++++++++++++++++++++++++++++//
     //++++++++ Vertex shader ++++++++//
     //+++++++++++++++++++++++++++++++//
@@ -1148,7 +1120,6 @@ void MathMod::CreateShaderProgram()
             }
             )";
 
-
 /*
             R"(#version 300 es
             #ifdef GL_ES
@@ -2092,11 +2063,9 @@ void MathMod::InitSpecularParameters()
 }
 
 MathMod::MathMod(QWidget *parent, uint nbthreads,
-                 uint initparGrid, uint initisoGrid, uint FactX, uint FactY,
-                 uint FactZ) :QOpenGLWidget(parent)
+                 uint initparGrid, uint initisoGrid, int * pt) :QOpenGLWidget(parent)
 {
-    //nbthreads = Threads[0];
-    PerlinNoise = new ImprovedNoise(4., 4., 4.);
+    //PerlinNoise = new ImprovedNoise(4., 4., 4.);
     latence = 10;
     Vgrid = Ugrid = 64;
     CutV = CutU = 0;
@@ -2107,8 +2076,7 @@ MathMod::MathMod(QWidget *parent, uint nbthreads,
     hauteur_fenetre = 2*wh;
     timer = new QBasicTimer();
     xyzactivated = uvactivated = uvactivated4D = 1;
-    if (memoryallocation(nbthreads, initparGrid, initisoGrid,
-                               FactX, FactY, FactZ) != 1)
+    if (memoryallocation(nbthreads, initparGrid, initisoGrid, pt) != 1)
         exit(0);
 }
 
@@ -2231,21 +2199,22 @@ void MathMod::ShowErrormessage()
     message.setTextFormat(Qt::RichText);
     int before, after;
     QString sortie = QString::fromStdString(stError.strError);
-    if (sortie.length() > (stError.iErrorIndex + 30))
-        after = 30;
+    if (sortie.length() > (stError.iErrorIndex + 20))
+        after = 20;
     else
         after = sortie.length() - stError.iErrorIndex;
     sortie.truncate(stError.iErrorIndex + after);
-    if (stError.iErrorIndex - 30 > 0)
-        before = 30;
+    if (stError.iErrorIndex - 20 > 0)
+        before = 20;
     else
         before = 0;
     sortie = sortie.remove(0, stError.iErrorIndex - before);
     sortie.replace("\t", " ");
     sortie.replace("\n", " ");
-    sortie.insert(before, " <font size=14  color=#FF0033>Error => </font>");
-    message.setText("Error at position: " + QString::number(stError.iErrorIndex) +
-                    "<br><br>" + "..." + sortie + "...");
+    sortie.insert(before, " <font color=#FF3300> -> </font>");
+    message.setText(" <font color=#FF6600> Error Type: </font>"+QString::fromStdString(stError.ErrorType)
+                    +"<br><font color=#FF6600> Error position: </font>" + QString::number(stError.iErrorIndex)
+                    +"<br><font color=#FF6600> Error Localization: </font>..."+ sortie +"...");
     message.adjustSize();
     message.exec();
     return;
@@ -2270,14 +2239,14 @@ void MathMod::ParametricSurfaceProcess(int type)
     {
         if (type == 3)
         {
-            ParObjet->masterthread->param4D = 1;
-            ParObjet->param4D = 1;
+            ParObjet->masterthread->param4D = true;
+            ParObjet->param4D = true;
             ParObjet->masterthread->param3d_C = false;
         }
         else
         {
-            ParObjet->masterthread->param4D = -1;
-            ParObjet->param4D = -1;
+            ParObjet->masterthread->param4D = false;
+            ParObjet->param4D = false;
             ParObjet->masterthread->param4d_C = false;
         }
         int result = ParsePar();
@@ -2298,7 +2267,7 @@ void MathMod::ParisoObjectProcess()
     if (!ParObjet->isRunning())
     {
         ParObjet->masterthread->param4D =
-            ParObjet->param4D = -1;
+            ParObjet->param4D = false;
         ParObjet->masterthread->param4d_C =
         ParObjet->masterthread->param3d_C = false;
         int result = ParsePar();
