@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2024 by Abderrahman Taha                                *
+ *   Copyright (C) 2025 by Abderrahman Taha                                *
  *                                                                         *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -24,7 +24,7 @@
 #include <sstream>
 #include <string>
 int Threads[3]={8,1,64};
-int CalculFactor[3]={4,4,4};
+int CalculFactor[6]={4,4,4,8,8};
 int InitParGrid=50;
 int InitIsoGrid=40;
 static bool MACOS = false;
@@ -118,11 +118,16 @@ void Parametersoptions::maxpargri_valueChanged(int value)
 
 ListeModelTexture
 Parametersoptions::LoadCollectionModels(QJsonObject &Jcollection,
-                                        jcollection &pariso, int argc)
+                                        jcollection &pariso)
 {
-    QFile fconllect(filecollection);
-    if (fconllect.exists() && ((argc > 1) || MACOS))
-        ReadJsonFile(filecollection, Collection);
+    if(JsCollectionFile !="")
+    {
+        QFile fconllect(JsCollectionFile);
+        if (fconllect.exists())
+            ReadJsonFile(JsCollectionFile, Collection);
+        else
+            ReadJsonFile(":/mathmodcollection.js", Collection);
+        }
     else
         ReadJsonFile(":/mathmodcollection.js", Collection);
 
@@ -268,36 +273,126 @@ void Parametersoptions::LoadConfig(int argc, char *argv[])
         argv1 = QString(argv[1]);
         if (!argv1.endsWith("/"))
             argv1 += "/";
-        filecollection = argv1 + filecollection;
-        fileconfig = argv1 + fileconfig;
-    }
-    /*
-    #ifdef Q_OS_MACOS
+
+        JsConfigFile = argv1 + "mathmodconfig.js";
+        JsCollectionFile = argv1 + "mathmodcollection.js";
+
+        QFile mathmodfileconfig(JsConfigFile);
+        if (!mathmodfileconfig.exists())
+        {
+            ReadJsonFile(":/mathmodconfig.js", JConfig);
+            QFile file(":/mathmodconfig.js");
+            file.copy(JsConfigFile);
+            QFile::setPermissions(JsConfigFile,
+                                  QFileDevice::ReadOwner | QFileDevice::WriteOwner);
+        }
         else
-      {
-            MACOS = true;
-            QString appDirPath = QApplication::applicationDirPath();
-            appDirPath = appDirPath.remove(fileconfig2.size()-5, 5);
-            filecollection   = appDirPath + "Resources/" + filecollection;
-            fileconfig       = appDirPath + "Resources/" + fileconfig;
-         }
-    #endif
-    */
-    QFile mathmodfileconfig(fileconfig);
-    if (!mathmodfileconfig.exists() && ((argc > 1) || MACOS))
-    {
-        QFile file3(":/mathmodconfig.js");
-        file3.copy(fileconfig);
-        QFile::setPermissions(fileconfig,
-                              QFileDevice::ReadOwner | QFileDevice::WriteOwner);
+        {
+            ReadJsonFile(JsConfigFile, JConfig);
+        }
+
+        QFile mathmodfilecollection(JsCollectionFile);
+        if (!mathmodfileconfig.exists())
+        {
+            // Make a new copy from MathMod's integrated collection file:
+            QFile file2(":/mathmodcollection.js");
+            QString str;
+            file2.open(QIODevice::ReadOnly | QIODevice::Text);
+            QTextStream stream(&file2);
+            str.append(stream.readAll());
+            str.replace("DOTSYMBOL", dotsymbol.toStdString().c_str());
+            QFile file(JsCollectionFile);
+            if (!file.open(QIODevice::WriteOnly))
+            {
+                std::cerr << "Cannot open file for writing: "
+                          << qPrintable(file.errorString()) << std::endl;
+            }
+            QTextStream out(&file);
+            out << str <<Qt::endl;
+            file.close();
+            file.copy(JsCollectionFile);
+            QFile::setPermissions(JsCollectionFile,
+                                  QFileDevice::ReadOwner | QFileDevice::WriteOwner);
+        }
     }
-
-    QFile fconf(fileconfig);
-    if (fconf.exists())
-        ReadJsonFile(fileconfig, JConfig);
     else
+    {
+        // Read the path to MathMod's config file from MathMod's integrated config file
         ReadJsonFile(":/mathmodconfig.js", JConfig);
+        if (JConfig["ReleaseInfos"].isObject())
+        {
+            QString str;
+            QJsonObject tmp = JConfig["ReleaseInfos"].toObject();
+            if((str = tmp["FileConfig"].toString())!= "")
+                JsConfigFile = str;
+            if((str = tmp["FileCollection"].toString())!= "")
+                JsCollectionFile = str;
+        }
+        #ifdef Q_OS_MACOS
+                MACOS = true;
+                QString appDirPath = QApplication::applicationDirPath();
+                if (appDirPath.endsWith("/"))
+                    appDirPath.lastIndexOf("/");
+                appDirPath.truncate(appDirPath.lastIndexOf("/")+1);
+                if(JsCollectionFile !="")
+                    JsCollectionFile   = appDirPath + JsCollectionFile;
+                if(JsConfigFile !="")
+                    JsConfigFile       = appDirPath + JsConfigFile;
+        #endif
 
+        // Check if JsConfigFile is there and read it, if not, read from the integrated one and create a new copy in the indicated location (if possible)
+        if(JsConfigFile !="")
+        {
+            QFile mathmodfileconfig(JsConfigFile);
+            if (!mathmodfileconfig.exists())
+            {
+                ReadJsonFile(":/mathmodconfig.js", JConfig);
+                QFile file(":/mathmodconfig.js");
+                if(JsConfigFile !="")
+                {
+                    file.copy(JsConfigFile);
+                    QFile::setPermissions(JsConfigFile,
+                                          QFileDevice::ReadOwner | QFileDevice::WriteOwner);
+                }
+            }
+            else
+            {
+                ReadJsonFile(JsConfigFile, JConfig);
+            }
+        }
+        else
+        {
+            ReadJsonFile(":/mathmodconfig.js", JConfig);
+        }
+
+        // Check if JsCollectionFile exist if not, read from the integrated one and create a new copy in the indicated location (if possible)
+        if(JsCollectionFile !="")
+        {
+            QFile mathmodfile(JsCollectionFile);
+            if (!mathmodfile.exists())
+            {
+                QFile file2(":/mathmodcollection.js");
+                QString str;
+                file2.open(QIODevice::ReadOnly | QIODevice::Text);
+                QTextStream stream(&file2);
+                str.append(stream.readAll());
+                str.replace("DOTSYMBOL", dotsymbol.toStdString().c_str());
+                QFile file(JsCollectionFile);
+                if (!file.open(QIODevice::WriteOnly))
+                {
+                    std::cerr << "Cannot open file for writing: "
+                              << qPrintable(file.errorString()) << std::endl;
+                }
+                QTextStream out(&file);
+                out << str <<Qt::endl;
+                file.close();
+                file.copy(JsCollectionFile);
+                QFile::setPermissions(JsCollectionFile,
+                                      QFileDevice::ReadOwner | QFileDevice::WriteOwner);
+            }
+        }
+    }
+    // Extract data from the config file:
     {
         if (JConfig["Localization"].isObject())
         {
@@ -323,44 +418,53 @@ void Parametersoptions::LoadConfig(int argc, char *argv[])
             model = tmp["Model"].toString();
         }
 
+        if (JConfig["CalculFactorConfig"].isObject())
+        {
+            QJsonObject tmp = JConfig["CalculFactorConfig"].toObject();
+            CalculFactor[0] = tmp["IsoFactX"].toInt();
+            CalculFactor[1] = tmp["IsoFactY"].toInt();
+            CalculFactor[2] = tmp["IsoFactZ"].toInt();
+            CalculFactor[3] = tmp["ParFactU"].toInt();
+            CalculFactor[4] = tmp["ParFactV"].toInt();
+        }
+
+        if (JConfig["ThreadsConfig"].isObject())
+        {
+            QJsonObject tmp = JConfig["ThreadsConfig"].toObject();
+            if (tmp["AutoDetect"].isBool() && tmp["AutoDetect"].toBool())
+                Threads[0] = QThread::idealThreadCount();
+            else
+                Threads[0] = tmp["ThreadsNumber"].toInt();
+            Threads[1] = tmp["MinThreadsNumber"].toInt();
+            Threads[2] = tmp["MaxThreadsNumber"].toInt();
+        }
+
         if (JConfig["Parameters"].isObject())
         {
-            IsoParam = JConfig["Parameters"].toObject();
-            if ((IsoParam)["IsoMaxGrid"].isDouble())
-                IsoMaxGrid = ((IsoParam)["IsoMaxGrid"]).toInt();
+            InitParameters = JConfig["Parameters"].toObject();
 
-            if ((IsoParam)["ParMaxGrid"].isDouble())
-                ParMaxGrid = ((IsoParam)["ParMaxGrid"]).toInt();
+            if ((InitParameters)["AutomaticInitGrid"].isBool()  && (InitParameters)["AutomaticInitGrid"].toBool())
+            {
+                InitIsoGrid = 2*Threads[0]*CalculFactor[0];
+                InitParGrid = 2*Threads[0]*CalculFactor[3];
+            }
+            else
+            {
+                if ((InitParameters)["InitIsoGrid"].isDouble())
+                    InitIsoGrid = (InitParameters)["InitIsoGrid"].toInt();
 
-            if ((IsoParam)["InitParGrid"].isDouble())
-                InitParGrid = (IsoParam)["InitParGrid"].toInt();
+                if ((InitParameters)["InitParGrid"].isDouble())
+                    InitParGrid = (InitParameters)["InitParGrid"].toInt();
+            }
+            if ((InitParameters)["IsoMaxGrid"].isDouble())
+                IsoMaxGrid = ((InitParameters)["IsoMaxGrid"]).toInt();
 
-            if ((IsoParam)["InitIsoGrid"].isDouble())
-                InitIsoGrid = (IsoParam)["InitIsoGrid"].toInt();
+            if ((InitParameters)["ParMaxGrid"].isDouble())
+                ParMaxGrid = ((InitParameters)["ParMaxGrid"]).toInt();
 
-            if ((IsoParam)["ScriptEditorFontSize"].isDouble())
-                scripteditorfontsize = (IsoParam)["ScriptEditorFontSize"].toInt();
+            if ((InitParameters)["ScriptEditorFontSize"].isDouble())
+                scripteditorfontsize = (InitParameters)["ScriptEditorFontSize"].toInt();
         }
-
-        QJsonObject tmp;
-        if (JConfig["WindowPosition"].isObject())
-        {
-            tmp = JConfig["WindowPosition"].toObject();
-            ControlX = tmp["ControlX"].toInt();
-            ControlY = tmp["ControlY"].toInt();
-            GlwinX = tmp["GlwinX"].toInt();
-            GlwinY = tmp["GlwinY"].toInt();
-        }
-
-        if (JConfig["WindowSize"].isObject())
-        {
-            tmp = JConfig["WindowSize"].toObject();
-            ControlW = tmp["ControlW"].toInt();
-            ControlH = tmp["ControlH"].toInt();
-            GlwinW = tmp["GlwinW"].toInt();
-            GlwinH = tmp["GlwinH"].toInt();
-        }
-
         if (JConfig["OpenGlConfig"].isObject())
         {
             QJsonObject tmp1, tmp2;
@@ -398,25 +502,6 @@ void Parametersoptions::LoadConfig(int argc, char *argv[])
             }
         }
 
-        if (JConfig["CalculFactorConfig"].isObject())
-        {
-            QJsonObject tmp = JConfig["CalculFactorConfig"].toObject();
-            CalculFactor[0] = tmp["FactX"].toInt();
-            CalculFactor[1] = tmp["FactY"].toInt();
-            CalculFactor[2] = tmp["FactZ"].toInt();
-        }
-
-        if (JConfig["ThreadsConfig"].isObject())
-        {
-            QJsonObject tmp = JConfig["ThreadsConfig"].toObject();
-            if (tmp["AutoDetect"].isBool() && tmp["AutoDetect"].toBool())
-                Threads[0] = QThread::idealThreadCount();
-            else
-                Threads[0] = tmp["ThreadsNumber"].toInt();
-            Threads[1] = tmp["MinThreadsNumber"].toInt();
-            Threads[2] = tmp["MaxThreadsNumber"].toInt();
-        }
-
         if (JConfig["ReleaseInfos"].isObject())
         {
             QJsonObject tmp = JConfig["ReleaseInfos"].toObject();
@@ -425,28 +510,4 @@ void Parametersoptions::LoadConfig(int argc, char *argv[])
             version = tmp["VersionNumber"].toString();
         }
     }
-    fullpath = fileconfig;
-    QFile mathmodfile(filecollection);
-    if (!mathmodfile.exists() && ((argc > 1) || MACOS))
-    {
-        QFile file2(":/mathmodcollection.js");
-        QString str;
-        file2.open(QIODevice::ReadOnly | QIODevice::Text);
-        QTextStream stream(&file2);
-        str.append(stream.readAll());
-        str.replace("DOTSYMBOL", dotsymbol.toStdString().c_str());
-        QFile file(filecollection);
-        if (!file.open(QIODevice::WriteOnly))
-        {
-            std::cerr << "Cannot open file for writing: "
-                      << qPrintable(file.errorString()) << std::endl;
-            return;
-        }
-        QTextStream out(&file);
-        out << str <<Qt::endl;
-        file.close();
-        file.copy(filecollection);
-        QFile::setPermissions(filecollection,
-                              QFileDevice::ReadOwner | QFileDevice::WriteOwner);
-    }
 }
